@@ -123,7 +123,9 @@ MainWindow::MainWindow(TerminalConfig &cfg,
             ) {
             move(Properties::Instance()->mainWindowPosition);
         }
-        restoreState(Properties::Instance()->mainWindowState);
+        if (Properties::Instance()->saveStateOnExit) {
+            restoreState(Properties::Instance()->mainWindowState);
+        }
     }
 
     consoleTabulator->setAutoFillBackground(true);
@@ -620,9 +622,8 @@ bool MainWindow::closePrompt(const QString &title, const QString &text)
     dia->setObjectName(QStringLiteral("exitDialog"));
     dia->setWindowTitle(title);
 
-    QCheckBox * dontAskCheck = new QCheckBox(tr("Do not ask again"), dia);
     QDialogButtonBox * buttonBox = new QDialogButtonBox(QDialogButtonBox::Yes | QDialogButtonBox::No, Qt::Horizontal, dia);
-    buttonBox->button(QDialogButtonBox::Yes)->setDefault(true);
+    buttonBox->button(QDialogButtonBox::No)->setDefault(true);
 
     connect(buttonBox, &QDialogButtonBox::accepted, dia, &QDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, dia, &QDialog::reject);
@@ -631,15 +632,10 @@ bool MainWindow::closePrompt(const QString &title, const QString &text)
     lay->addWidget(new QLabel(QStringLiteral("<center>") + text + QStringLiteral("</center>")));
     lay->addWidget(new QLabel(QStringLiteral("<center><i>") + tr("A process is running.") + QStringLiteral("</i></center>")));
     lay->addStretch();
-    lay->addWidget(dontAskCheck);
     lay->addWidget(buttonBox);
     dia->setLayout(lay);
 
     bool res(dia->exec() == QDialog::Accepted);
-    if (res)
-    {
-        Properties::Instance()->askOnExit = !dontAskCheck->isChecked();
-    }
     dia->deleteLater();
     return res;
 }
@@ -651,42 +647,33 @@ void MainWindow::closeEvent(QCloseEvent *ev)
         // the session is ended explicitly (e.g., by ctrl-d); prompt doesn't make sense
         || consoleTabulator->terminalHolder()->findChildren<TermWidget*>().count() == 0
         // there is no running process
-        || !consoleTabulator->hasRunningProcess())
+        || !consoleTabulator->hasRunningProcess()
+        // ask user for canceling otherwise
+        || closePrompt(tr("Exit QTerminal"), tr("Are you sure you want to exit?")))
     {
         disconnect(m_bookmarksDock, &QDockWidget::visibilityChanged,
                    this, &MainWindow::bookmarksDock_visibilityChanged); // prevent crash
-        // #80 - do not save state and geometry in drop mode
-        if (!m_dropMode) {
-            if (Properties::Instance()->savePosOnExit) {
+        // do not save state and geometry in drop mode
+        if (!m_dropMode)
+        {
+            if (Properties::Instance()->savePosOnExit)
+            {
                 Properties::Instance()->mainWindowPosition = pos();
             }
-            if (Properties::Instance()->saveSizeOnExit) {
+            if (Properties::Instance()->saveSizeOnExit)
+            {
                 Properties::Instance()->mainWindowSize = size();
+                Properties::Instance()->windowMaximized = isMaximized();
+            }
+            if (Properties::Instance()->saveStateOnExit)
+            {
+                Properties::Instance()->mainWindowState = saveState();
             }
-            Properties::Instance()->windowMaximized = isMaximized();
-            Properties::Instance()->mainWindowState = saveState();
         }
         rebuildActions(); // shortcuts may have changed by another running instance
         Properties::Instance()->saveSettings();
-        for (int i = consoleTabulator->count(); i > 0; --i) {
-            consoleTabulator->removeTab(i - 1);
-        }
-        ev->accept();
-        return;
-    }
-
-    // ask user for cancel only when there is at least one terminal active in this window
-    if (closePrompt(tr("Exit QTerminal"), tr("Are you sure you want to exit?")))
-    {
-        disconnect(m_bookmarksDock, &QDockWidget::visibilityChanged,
-                   this, &MainWindow::bookmarksDock_visibilityChanged);
-        Properties::Instance()->mainWindowPosition = pos();
-        Properties::Instance()->mainWindowSize = size();
-        Properties::Instance()->mainWindowState = saveState();
-        Properties::Instance()->windowMaximized = isMaximized();
-        rebuildActions();
-        Properties::Instance()->saveSettings();
-        for (int i = consoleTabulator->count(); i > 0; --i) {
+        for (int i = consoleTabulator->count(); i > 0; --i)
+        {
             consoleTabulator->removeTab(i - 1);
         }
         ev->accept();
