@@ -28,6 +28,9 @@
 #include "terminalconfig.h"
 #include "dbusaddressable.h"
 
+namespace LayerShellQt {
+    class Window;
+}
 
 class QToolButton;
 
@@ -46,6 +49,8 @@ public:
 
     void rebuildActions();
 
+    bool closePrompt(const QString &title, const QString &text);
+
     #ifdef HAVE_QDBUS
     QDBusObjectPath getActiveTab();
     QList<QDBusObjectPath> getTabs();
@@ -55,6 +60,7 @@ public:
 
 protected:
      bool event(QEvent* event) override;
+     void showEvent(QShowEvent* event) override;
 
 private:
     QActionGroup *tabPosition, *scrollBarPosition, *keyboardCursorShape;
@@ -86,6 +92,7 @@ private:
     void enableDropMode();
     QToolButton *m_dropLockButton;
     bool m_dropMode;
+    LayerShellQt::Window *m_layerWindow;
     QxtGlobalShortcut m_dropShortcut;
     void realign();
     void setDropShortcut(const QKeySequence& dropShortCut);
